==> jffnms_0.7.8.orig.tar.gz: jffnms-0.7.8/htdocs/view_performance.php <==
<? 
    include ("auth.php");  

    function performance_graphs_header ($graph_types_show,$graph_defaults) {
	global $REQUEST_URI,$graph_time_start,$day,$hour,$graph_time_stop,$graph_time_stop_hour,$graph_time_start_hour,
	    $graph_type,$jffnms_rel_path,$graph_time_preset;

	$graph_time_presets = array();

	$graph_time_presets[0] = "No Preset";
	$graph_time_presets[-(60*10)] = "Last 10 Minutes";
	$graph_time_presets[-($hour/2)] = "Last Half Hour";
	$graph_time_presets[-$hour] = "Last Hour";
	$graph_time_presets[-$hour*6] = "Last 6 Hours";
	$graph_time_presets[-$day] = "Last Day";
	$graph_time_presets[-$day*2] = "Last 2 Days";
	$graph_time_presets[-$day*7] = "Last Week";
	$graph_time_presets[-$day*30] = "Last Month";
	$graph_time_presets[-$day*360] = "Last Year";

	$colspan=2;

	$shortcuts=Array();
	$shortcuts[] = linktext(adm_image("$jffnms_rel_path/images/refresh.png"),"$REQUEST_URI&refresh=");
        $shortcuts[] = linktext("(stop refresh)","$REQUEST_URI&refresh=0");

	if (!$GLOBALS["client_id"]) {
	    if (profile("ADMIN_HOSTS")) {
		$shortcuts[] = linktext(adm_image("images/edit.png","","",0,0,"Edit"),"$jffnms_rel_path/admin/adm/adm_interfaces.php?".$_SERVER[QUERY_STRING]);
		$shortcuts[] = linktext(adm_image("images/tool.png","","",0,0,"Edit"),"$jffnms_rel_path/admin/tools.php?".$_SERVER["QUERY_STRING"]);
	    }
	    $colspan++; 
	}

	$shortcuts[] = linktext(adm_image("images/text.png","","",0,0,"Report"),"$jffnms_rel_path/admin/reports/state_report.php?".$_SERVER[QUERY_STRING]);


	echo "
	<SCRIPT>
	function go_preset(select){
	    var time = select.options[select.selectedIndex].value;
	    location.href = '$REQUEST_URI'+'&graph_time=preset&graph_time_preset='+time;
	    return true;
	}
	</SCRIPT>
	";

	adm_table("100%","1","center",0,0,0,"");
	std_table_row();

	adm_table_cell( "<font size=4><b>Performance Trends</b></font>&nbsp;&nbsp;".
		    join(" | ",$shortcuts)
		    ,"center",$colspan);

	if ($GLOBALS["client_id"]) 
	    adm_control_option("Logout","_top","$jffnms_rel_path/?logout=1&OldAuth=".$GLOBALS["PHP_AUTH_USER"],"logoff.png"); 

	adm_table_row_close();
    
	std_table_row();
	adm_table_header_cell("Graph Type","center");
	adm_table_header_cell("Time Span","center");
	adm_table_header_cell("Time Preset","center");
	adm_table_row_close();

	std_table_row();
	adm_form("","GET");
	reports_pass_options();
	hidden("graph_time","nopreset",1);

	echo custom_table_cell_open("","","","center");

	arsort($graph_types_show);

	$select_aux = html_indenter()."<select name='graph_type[]' size=3 multiple OnDblClick='javascript: this.form.submit();'>\n";
	foreach ($graph_types_show as $graph_id=>$graph_description) {

	    if ((in_array($graph_id,$graph_type)) ||  //graph we're looking for or
		((in_array(1,$graph_type)) && (in_array($graph_id,$graph_defaults)))) //no graph selected and default graph
		$selected = 1; 
	    else 
		$selected = 0;

	    //debug ("$graph_id Sel(".join($graph_type,",").") Def(".join($graph_defaults,",").") = $selected"); 

	    $select_aux1 .= html_indenter()."<option value='$graph_id' ".(($selected==1)?"Selected":"").">$graph_description</option>\n";
	}
	$select_aux2 = html_indenter()."</select>\n";

	echo $select_aux;    
	html_indent_more();
	echo $select_aux1;
	html_indent_less();
	echo $select_aux2;

	adm_table_td_close();

	//TIME SPAN Table
	echo custom_table_cell_open("","","","center");
	adm_table("100%","0","center",0,1,0,"");

	std_table_row();
	adm_table_header_cell("From: ","left");
	adm_table_cell(select_date("graph_time_start",$graph_time_start,7,true,$graph_time_start_hour),"left",1,1);
	adm_table_cell(adm_form_submit("View"),"center",1,2);
	adm_table_row_close();

	std_table_row();
	adm_table_header_cell("To: ","left");
	adm_table_cell(select_date("graph_time_stop",$graph_time_stop,7,true,$graph_time_stop_hour),"left",1,1);
	adm_table_row_close();

	std_table_row();
	adm_table_row_close();

	adm_table_td_close();
	adm_table_close();
	//TIME SPAN Table end
    
	adm_table_cell(
	    select_custom("graph_time_preset",$graph_time_presets,$graph_time_preset,"go_preset(this)").
	    "<br><small>Now: ".date("Y-m-d H:i:s",time())."</small>",
	    "center",1);

	adm_form_close();
	adm_table_row_close();
	adm_table_close();
	flush();
	
    } //function

    function performance_graphs_list ($interfaces, $graph_type, $filters, $use_interfaces = NULL) {
	
	$graphics = array();
	$graph_types_show = array();
	$graph_defaults = array(); 

	$filters["with_graph"]=1; //force graph fields
	$interfaces->get($use_interfaces,$filters); //get interfaces

	while ($graph = $interfaces->fetch()) {
	    //debug ($graph);
	
	    $graph_types_show[$graph["graph_type"]]=$graph["graph_type_description"];
	    $graph_defaults[$graph["graph_type_default"]]=1;
	
	    $file = "interface-".$graph["id"];
	    $graphic_aux2=array();	    

    	    if (((in_array(1,$graph_type) and ($graph["graph_type"]==$graph["graph_type_default"]))) || //default graph or
		in_array($graph["graph_type"],$graph_type) || in_array($graph["graph_type_graph1"],$graph_type)) {  //match graph type
	
		    if ($graph["graph_type_graph1"]) { 
    	    		$graphic_aux["image"]="i".$graph["id"]."-".uniqid("").".png";
			$graphic_aux["type"]=$graph["graph_type_graph1"];
	    		$graphic_aux["sx"]=$graph["graph_type_graph1_sx"];
	    		$graphic_aux["sy"]=$graph["graph_type_graph1_sy"];

	    		$graphic_aux2["graph1"]=$graphic_aux;
		    }

		    if ($graph["graph_type_graph2"]) { 
    	    		$graphic_aux["image"]="i".$graph["id"]."-".uniqid("").".png";
			$graphic_aux["type"]=$graph["graph_type_graph2"];
	    		$graphic_aux["sx"]=$graph["graph_type_graph2_sx"];
	    		$graphic_aux["sy"]=$graph["graph_type_graph2_sy"];

	    		$graphic_aux2["graph2"]=$graphic_aux;
		    }
		    
		    //FIXME Include all description fields in the title
		    $last_date = " ".date("Y-m-d H:i:s",$graph["last_poll_date"]);
		    $title = $graph["host_name"]." ".$graph["zone_shortname"]." ".$graph["interface"]." ".$graph["client_shortname"]." ".$graph["description"];
		    $title = str_replace("  ","",$title);
		    $len_aux1 = (($graph["graph_type_graph1_sx"])/6)-strlen($last_date)-2; //graph length/size of character - length of date - margin
		    $title = substr($title,0,$len_aux1);
		    $title = str_pad($title,$len_aux1," ").(($graph["last_poll_date"] > 1)?$last_date:"");
		    
		    $graphic_aux2["title"]=$title;
		    $graphic_aux2["aggr"]=$graph["graph_type_agg"];
		    $graphic_aux2["id"]=$graph["id"];
		    $graphic_aux2["host"]=$graph["host"];
		    $graphic_aux2["graph_type"]=$graph["graph_type"];
		    $graphic_aux2["graph_description"]=$graph["graph_type_description"];
		    
		    $graphics[] = $graphic_aux2;
		} // if is used
	} //while
	$graph_defaults = array_keys($graph_defaults);

	//debug ($graphics);	
	//debug ($graph_types_show);
	//debug ($graph_defaults);
    
	return array($graphics,$graph_types_show,$graph_defaults);
    } //performance_graphs_list function

    $hour = (60*60);
    $day = $hour*24;

    if ($map_profile = profile("MAP")) $map_id = $map_profile; //fixed map

    $interfaces = $jffnms->get("interfaces");
    $scale_legend = "u Micro, m Milli, k Kilo, M Mega, G Giga";

    if ($refresh==NULL) $refresh=60*5; //5 minute refresh

    $today = date("Y-m-d",time());

    if (empty($view_type)) $view_type = "html";
    if (!empty($want_graph)) {
	$view_type = "graph";
	if (empty($graph_type)) $graph_type = $want_graph;
    }
    
    if (empty($graph_type)) $graph_type = 1;
    if (!is_array($graph_type)) $graph_type = array($graph_type); //select default graph

    if ($map_id=="") $map_id = 1;

    if ($graph_time=="") $graph_time = "preset"; //default is use preset
    
    if ($graph_time=="preset") { //preset
	if (!isset($graph_time_preset)) $graph_time_preset = -$day; //preset default to Last Day 

	$graph_time_start_unix = $graph_time_preset;
	$graph_time_stop_unix = 0; //set STOP to Now

	//set the fields to the preset time, just to show them and be used when clicking on View
	$graph_time_start = date("Y-m-d",(time() + $graph_time_start_unix)); //get day
	$graph_time_start_hour = round ((time() + $graph_time_start_unix - strtotime($graph_time_start))/(30*60)) * (30*60); //get 30 minutes round

	$graph_time_stop = $today;
	$graph_time_stop_hour = round ((time() - strtotime($graph_time_stop))/(30*60)) * (30*60);
    } else { //no preset
	
	unset ($graph_time_preset);
	
	//calculate the Unix Times
    	$graph_time_start_unix = strtotime($graph_time_start)+$graph_time_start_hour;
	$graph_time_stop_unix  = strtotime($graph_time_stop)+$graph_time_stop_hour;
    }
    
    //debug("TYPE : $graph_time\nSTART: $graph_time_start $graph_time_start_hour = $graph_time_start_unix\nSTOP : $graph_time_stop $graph_time_stop_hour = $graph_time_stop_unix");

    //get graphics array with all needed data
    list ($graphics, $graph_types_show, $graph_defaults) = 
	performance_graphs_list (&$interfaces, $graph_type, reports_make_interface_filter(), $use_interfaces);

    switch ($view_type) {
	case "html": 
	    adm_header("Performance Trends","D0DCE0");

	    if (count($graphics)==0) { //probably the user was on a restricted map and tried to see a forbidden interface id 
    		echo "<center><b>Error: No Interface Graphs were returned.</b></center>";
		die();
	    }
    
	    //show header (selector)
	    performance_graphs_header ($graph_types_show,$graph_defaults);

	    //debug ($graphics);

	    if (($graph_time_stop_unix >0) && (($graph_time_start_unix > ($graph_time_stop_unix-500)))) {
    		echo "<center><b>'From' is more recent than 'To'<b></center>";
    		die();
	    }

	    adm_table("100%","1");
	break;
	
	case "graph": 
	    header ("Content-Type: image/png");
	break;
    }
    
    $aggregation = array();
    
    foreach ($graphics as $graphic) {
	//debug($graphic);
	if ($view_type=="html") echo custom_table_row_open("",0,"","top");

	if ($graphic) {
	    $graph_type_name = $graphic["graph1"]["type"];
	
	    // Generate the graphs
	    
    	    if ($graphic["graph1"])
		$ret1 = performance_graph(&$interfaces,$graphic["id"],$images_real_path."/".$graphic["graph1"]["image"],
		    $graphic["graph1"]["type"],$graphic["graph1"]["sx"],$graphic["graph1"]["sy"],
		    $graphic["title"],$graph_time_start_unix,$graph_time_stop_unix);

	    if ($graphic["graph2"])
		$ret2 = performance_graph(&$interfaces,$graphic["id"],$images_real_path."/".$graphic["graph2"]["image"],
		    $graphic["graph2"]["type"],$graphic["graph2"]["sx"],$graphic["graph2"]["sy"],
	    	    $graphic["title"],$graph_time_start_unix,$graph_time_stop_unix);
	
	    // show the graphs
	    switch ($view_type) {
		case "html": 
		    if (($graphic["graph1"]) && ($ret1!==false))
			adm_table_cell(adm_image($images_rel_path."/".$graphic["graph1"]["image"],"","",0,0,$scale_legend),
			    "center",(!isset($graphic["graph2"])?"2":"1"));
		    
		    if (($graphic["graph2"]) && ($ret2!==false))
			adm_table_cell(adm_image($images_rel_path."/".$graphic["graph2"]["image"],"","",0,0,$scale_legend),"center");
		break;

		case "graph":
		    if (($graphic["graph1"]) && ($ret1!==false) && ($want_graph==$graphic["graph1"]["type"]))
			echo join ("",file($images_real_path."/".$graphic["graph1"]["image"]));
		break;
	    }
	
	    //aggregation
	    if ($graphic["aggr"]==1) { //allow aggregation
		$aggregation[$graph_type_name]["ids"][] = $graphic["id"];
		$aggregation[$graph_type_name]["description"] = $graphic["graph_description"];
	    }
	} 
	
	if ($view_type=="html") {
	    adm_table_row_close();
	    if ((!$graphic) || ($ret1===false) || ($ret2===false)) 
		table_row("<small>The RRDTool files for Interface ID ".$graphic["id"]." (from Host ID ".$graphic["host"]."), has not been created by the Poller Process yet.</small>","center",2);
	}

	flush();
    }

    //debug ($aggregation);
        
    foreach ($aggregation as $agg_type=>$agg_data) //for each graph type with aggregation
	if (count($agg_data["ids"]) > 1) { //more than 1 interface of this graph type

	    $image_title=$agg_data["description"]." Aggregation ".(($map_name!="")?"of $map_name":"");

	    $filename = "aggr-".uniqid("").".png";

	    $ret3 = performance_graph (&$interfaces,$agg_data["ids"],"$images_real_path/$filename",$agg_type."_aggregation",
		500,175, $image_title,$graph_time_start_unix,$graph_time_stop_unix); //FIXME Fixed Size

	    if ($ret3) 
		switch ($view_type) {
		    case "html":
			table_row(adm_image("$images_rel_path/$filename","","",0,0,$scale_legend),"center",2);
		    break;
		    
		    case "graph":
		    if ($want_graph=="aggr")
			echo join ("",file($images_real_path."/$filename"));
		    break;
		}

	    flush();
	}

    if ($view_type=="html") adm_footer();
?>

==> jffnms_0.7.9.orig.tar.gz: jffnms-0.7.9/htdocs/view_performance.php <==
<? 
    include ("auth.php");  

    function performance_graphs_header ($graph_types_show,$graph_defaults, $number_of_interfaces) {
	global $REQUEST_URI,$graph_time_start,$day,$hour,$graph_time_stop,$graph_time_stop_hour,$graph_time_start_hour,
	    $graph_type,$jffnms_rel_path,$graph_time_preset;

	$graph_time_presets = array();

	$graph_time_presets[0] = "No Preset";
	$graph_time_presets[-(60*10)] = "Last 10 Minutes";
	$graph_time_presets[-($hour/2)] = "Last Half Hour";
	$graph_time_presets[-$hour] = "Last Hour";
	$graph_time_presets[-$hour*6] = "Last 6 Hours";
	$graph_time_presets[-$day] = "Last Day";
	$graph_time_presets[-$day*2] = "Last 2 Days";
	$graph_time_presets[-$day*7] = "Last Week";
	$graph_time_presets[-$day*30] = "Last Month";
	$graph_time_presets[-$day*360] = "Last Year";

	$colspan=2;

	$shortcuts = array();
	$shortcuts[] = linktext(adm_image("$jffnms_rel_path/images/refresh.png"),"$REQUEST_URI");
	$shortcuts[] = "<a href='#' OnClick=\"javascript: if (self.no_refresh!=1) { ".
			"self.no_refresh = 1; this.innerHTML='<font size=1>(refresh stopped)</font>'; } ".
			"else document.location = '".$REQUEST_URI."&".rand(0,10)."'; \"><font size=1>(stop refresh)</font></a>\n";
	
	if (!$GLOBALS["client_id"]) {
	    if (profile("ADMIN_HOSTS")) {
		$shortcuts[] = linktext(adm_image("images/edit.png","","",0,0,"Edit"),"$jffnms_rel_path/admin/adm/adm_interfaces.php?".$_SERVER[QUERY_STRING]);
		$shortcuts[] = linktext(adm_image("images/tool.png","","",0,0,"Edit"),"$jffnms_rel_path/admin/tools.php?".$_SERVER["QUERY_STRING"]);
	    }
	    $colspan++; 
	}

	$shortcuts[] = linktext(adm_image("images/text.png","","",0,0,"Report"),"$jffnms_rel_path/admin/reports/state_report.php?".$_SERVER[QUERY_STRING]);

	echo "<SCRIPT>\n";
	
	echo "function go_preset(select){\n";
	echo "\tvar time = select.options[select.selectedIndex].value;\n";
	echo "\tlocation.href = '$REQUEST_URI'+'&graph_time=preset&graph_time_preset='+time;\n";
	echo "\treturn true;\n";
	echo "}\n";

	echo "function select_all(field_aux) {\n";
	echo "\t field = document.getElementById(field_aux);\n";
        echo "\t if (field)\n";
        echo "\t\t for (i = 0; i < field.length; i++)\n";
    	echo "\t\t\t field[i].selected = true;\n";
	echo "}\n";

	echo "</SCRIPT>\n";

	adm_table("100%","1","center",0,0,0,"");
	std_table_row();

	adm_table_cell("<font size=4><b>Performance Trends</b></font>","center",$colspan-1);
	adm_table_cell(join(" | ",$shortcuts),"center",1);

	if ($GLOBALS["client_id"]) 
	    adm_control_option("Logout","_top","$jffnms_rel_path/?logout=1&OldAuth=".$GLOBALS["PHP_AUTH_USER"],"logoff.png"); 

	adm_table_row_close();
    
	std_table_row();
	adm_table_header_cell("Graph Types ".
	    linktext("</b><font size=1>[ all ]</font>","javascript: select_all('graph_type[]');"),"center");
	adm_table_header_cell("Time Span","center");
	adm_table_header_cell("Time Preset","center");
	adm_table_row_close();

	std_table_row();
	adm_form("","GET");
	reports_pass_options();
	hidden("graph_time","nopreset",1);

	echo custom_table_cell_open("","","","center");

	arsort($graph_types_show);

	$select_aux = html_indenter()."<select name='graph_type[]' id='graph_type[]' size=3 multiple OnDblClick='javascript: this.form.submit();'>\n";
	foreach ($graph_types_show as $graph_id=>$graph_description) {

	    if ((in_array($graph_id,$graph_type)) ||  //graph we're looking for or
		((in_array(1,$graph_type)) && (in_array($graph_id,$graph_defaults)))) //no graph selected and default graph
		$selected = 1; 
	    else 
		$selected = 0;

	    //debug ("$graph_id Sel(".join($graph_type,",").") Def(".join($graph_defaults,",").") = $selected"); 

	    $select_aux1 .= html_indenter()."<option value='$graph_id' ".(($selected==1)?"Selected":"").">$graph_description</option>\n";
	}
	$select_aux2 = html_indenter()."</select>\n";

	echo $select_aux;    
	html_indent_more();
	echo $select_aux1;
	html_indent_less();
	echo $select_aux2;
	
	if ($number_of_interfaces > 1)
	    echo "<br>".checkbox_value("only_aggr",1,($GLOBALS["only_aggr"]==1)?1:0)."<font size=1>Show Only Aggregate</font>";

	adm_table_td_close();

	//TIME SPAN Table
	echo custom_table_cell_open("","","","center");
	adm_table("100%","0","center",0,1,0,"");

	std_table_row();
	adm_table_header_cell("From: ","left");
	adm_table_cell(select_date("graph_time_start",$graph_time_start,7,true,$graph_time_start_hour),"left",1,1);
	adm_table_cell(adm_form_submit("View"),"center",1,2);
	adm_table_row_close();

	std_table_row();
	adm_table_header_cell("To: ","left");
	adm_table_cell(select_date("graph_time_stop",$graph_time_stop,7,true,$graph_time_stop_hour),"left",1,1);
	adm_table_row_close();

	std_table_row();
	adm_table_row_close();

	adm_table_td_close();
	adm_table_close();
	//TIME SPAN Table end
    
	adm_table_cell(
	    select_custom("graph_time_preset",$graph_time_presets,$graph_time_preset,"go_preset(this)").
	    "<br><small>Now: ".date("Y-m-d H:i:s",time())."</small>",
	    "center",1);

	adm_form_close();
	adm_table_row_close();
	
	adm_table_close();
	flush();
	
    } //function

    function performance_graphs_list ($interfaces, $graph_type, $filters, $use_interfaces = NULL) {
	
	$graphics = array();
	$graph_types_show = array();
	$graph_defaults = array(); 
	$interfaces_ids = array();

	$filters["with_graph"] = 1; //force graph fields
	$cant = $interfaces->get($use_interfaces,$filters); //get interfaces

	if ($cant > 0) {			// if we have interfaces to show

	    if (function_exists("gd_info")) {	// PHP >= 4.3.0
		$gd_aux = gd_info();		// This is to fix Debian PHP that used a not boundled GD, with other fonts
	        $gd_font_size = (strpos($gd_aux["GD Version"],"bundled")!==false)?6:6.7;	//If its not bundled RRDtool uses 8 px fonts
		unset ($gd_aux);
	    } else
		$gd_font_size = 6;
	
	    while ($graph = $interfaces->fetch()) {
		//debug ($graph);
	
	        $graph_types_show[$graph["graph_type"]]=$graph["graph_type_description"];
		$graph_defaults[$graph["graph_type_default"]]=1;
	
	        $file = "interface-".$graph["id"];
		$interface_ids[$graph["id"]]=1;
	    
		$graphic_aux2=array();	    

    		if (((in_array(1,$graph_type) and ($graph["graph_type"]==$graph["graph_type_default"]))) || //default graph or
		    in_array($graph["graph_type"],$graph_type) || in_array($graph["graph_type_graph1"],$graph_type)) {  //match graph type
	
		    if ($graph["graph_type_graph1"]) { 
    	    		$graphic_aux["image"]="i".$graph["id"]."-".uniqid("").".png";
			$graphic_aux["type"]=$graph["graph_type_graph1"];
	    		$graphic_aux["sx"]=$graph["graph_type_graph1_sx"];
	    		$graphic_aux["sy"]=$graph["graph_type_graph1_sy"];

	    		$graphic_aux2["graph1"]=$graphic_aux;
		    }

		    if ($graph["graph_type_graph2"]) { 
    	    		$graphic_aux["image"]="i".$graph["id"]."-".uniqid("").".png";
			$graphic_aux["type"]=$graph["graph_type_graph2"];
	    		$graphic_aux["sx"]=$graph["graph_type_graph2_sx"];
	    		$graphic_aux["sy"]=$graph["graph_type_graph2_sy"];

	    		$graphic_aux2["graph2"]=$graphic_aux;
		    }
		    
		    //FIXME Include all description fields in the title
		    $last_date = " ".date("Y-m-d H:i:s",$graph["last_poll_date"]);
		    $title = $graph["host_name"]." ".$graph["zone_shortname"]." ".$graph["interface"]." ".$graph["client_shortname"]." ".$graph["description"];
		    $title = str_replace("  ","",$title);
		    $len_aux1 = (($graph["graph_type_graph1_sx"])/$gd_font_size)-strlen($last_date)-2; //graph length/size of character - length of date - margin
		    $title = substr($title,0,$len_aux1);
		    $title = str_pad($title,$len_aux1," ").(($graph["last_poll_date"] > 1)?$last_date:"");
		    
		    $graphic_aux2["title"]=$title;
		    $graphic_aux2["aggr"]=$graph["graph_type_agg"];
		    $graphic_aux2["id"]=$graph["id"];
		    $graphic_aux2["host"]=$graph["host"];
		    $graphic_aux2["graph_type"]=$graph["graph_type"];
		    $graphic_aux2["graph_description"]=$graph["graph_type_description"];
		    
		    $graphics[] = $graphic_aux2;
		} // if is used
	    } //while

	    $graph_defaults = array_keys($graph_defaults);
	}

	//debug ($graphics);	
	//debug ($graph_types_show);
	//debug ($graph_defaults);
    
	return array($graphics,$graph_types_show,$graph_defaults, count($interface_ids));
    } //performance_graphs_list function

    $hour = (60*60);
    $day = $hour*24;

    if ($map_profile = profile("MAP")) $map_id = $map_profile; //fixed map
    if ($client_profile = profile("CUSTOMER")) $client_id = $client_profile; //fixed customer

    $interfaces = $jffnms->get("interfaces");
    $scale_legend = "u Micro, m Milli, k Kilo, M Mega, G Giga";

    if ($refresh_time==NULL) $refresh_time=60*5; //5 minute refresh

    $today = date("Y-m-d",time());

    if (empty($view_type)) $view_type = "html";
    if (!empty($want_graph)) {
	$view_type = "graph";
	if (empty($graph_type)) $graph_type = $want_graph;
    }
    
    if (empty($graph_type)) $graph_type = 1;
    if (!is_array($graph_type)) $graph_type = array($graph_type); //select default graph

    if ($map_id=="") $map_id = 1;

    if ($graph_time=="") $graph_time = "preset"; //default is use preset
    
    if ($graph_time=="preset") { //preset
	if (!isset($graph_time_preset)) $graph_time_preset = -$day; //preset default to Last Day 

	$graph_time_start_unix = $graph_time_preset;
	$graph_time_stop_unix = 0; //set STOP to Now

	//set the fields to the preset time, just to show them and be used when clicking on View
	/*
	$graph_time_start = date("Y-m-d",(time() + $graph_time_start_unix)); //get day
	$graph_time_start_hour = round ((time() + $graph_time_start_unix - strtotime($graph_time_start))/(30*60)) * (30*60); //get 30 minutes round

	$graph_time_stop = $today;
	$graph_time_stop_hour = round ((time() - strtotime($graph_time_stop))/(30*60)) * (30*60);
	*/

	$graph_time_start = date("Y-m-d",(time() + $graph_time_start_unix)); //get day
	$graph_time_start_hour = round ((time() + $graph_time_start_unix - strtotime($graph_time_start))/60) * 60; //get 1 minutes round
	$graph_time_stop = $today;
	$graph_time_stop_hour = round ((time() - strtotime($graph_time_stop))/60) * 60;

    } else { //no preset
	
	unset ($graph_time_preset);
	
	//calculate the Unix Times
    	$graph_time_start_unix = strtotime($graph_time_start)+$graph_time_start_hour;
	$graph_time_stop_unix  = strtotime($graph_time_stop)+$graph_time_stop_hour;
    }
    
    //debug("TYPE : $graph_time\nSTART: $graph_time_start $graph_time_start_hour = $graph_time_start_unix\nSTOP : $graph_time_stop $graph_time_stop_hour = $graph_time_stop_unix");

    //get graphics array with all needed data
    list ($graphics, $graph_types_show, $graph_defaults, $number_of_interfaces) = 
	performance_graphs_list (&$interfaces, $graph_type, reports_make_interface_filter(), $use_interfaces);

    switch ($view_type) {
	case "html": 
	    adm_header("Performance Trends","D0DCE0");
	    
	    echo 
		"<STYLE>\n".
		" td { font-size: 10pt; }\n".
		"</STYLE>\n";
	    
	    if (count($graphics)==0) { //probably the user was on a restricted map and tried to see a forbidden interface id 
    		echo "<center><b>Error: No Interface Graphs were returned.</b></center>";
		die();
	    }
    
	    //show header (selector)
	    performance_graphs_header ($graph_types_show,$graph_defaults, $number_of_interfaces);

	    //debug ($graphics);

	    if (($graph_time_stop_unix >0) && (($graph_time_start_unix > ($graph_time_stop_unix-500)))) {
    		echo "<center><b>'From' is more recent than 'To'<b></center>";
    		die();
	    }

	    adm_table("100%","1");
	break;
	
	case "graph": 
	    header ("Content-Type: image/png");
	break;
    }
    
    $aggregation = array();

    if ($only_top!=1)    
    foreach ($graphics as $graphic) {
	//debug($graphic);

	if ($only_aggr!=1)
	    if ($view_type=="html") 
		echo custom_table_row_open("",0,"","top");

	if ($graphic) {
	    $graph_type_name = $graphic["graph1"]["type"];
	
	    // Generate the graphs
	    
    	    if ($graphic["graph1"])
		$ret1 = performance_graph(&$interfaces,$graphic["id"],$images_real_path."/".$graphic["graph1"]["image"],
		    $graphic["graph1"]["type"],$graphic["graph1"]["sx"],$graphic["graph1"]["sy"],
		    $graphic["title"],$graph_time_start_unix,$graph_time_stop_unix);

	    if ($graphic["graph2"])
		$ret2 = performance_graph(&$interfaces,$graphic["id"],$images_real_path."/".$graphic["graph2"]["image"],
		    $graphic["graph2"]["type"],$graphic["graph2"]["sx"],$graphic["graph2"]["sy"],
	    	    $graphic["title"],$graph_time_start_unix,$graph_time_stop_unix);
	
	    // show the graphs
	    if ($only_aggr!=1)
	    switch ($view_type) {
		case "html": 
		    if (($graphic["graph1"]) && ($ret1!==false))
			adm_table_cell(adm_image($images_rel_path."/".$graphic["graph1"]["image"],"","",0,0,$scale_legend),
			    "center",(!isset($graphic["graph2"])?"2":"1"));
		    
		    if (($graphic["graph2"]) && ($ret2!==false))
			adm_table_cell(adm_image($images_rel_path."/".$graphic["graph2"]["image"],"","",0,0,$scale_legend),"center");
		break;

		case "graph":
		    if (($graphic["graph1"]) && ($ret1!==false) && ($want_graph==$graphic["graph1"]["type"]))
			echo join ("",file($images_real_path."/".$graphic["graph1"]["image"]));
		break;
	    }
	
	    //aggregation
	    if ($graphic["aggr"]==1) { //allow aggregation
		$aggregation[$graph_type_name]["ids"][] = $graphic["id"];
		$aggregation[$graph_type_name]["description"] = $graphic["graph_description"];
	    }
	} 
	
	if ($view_type=="html") {

	    if ($only_aggr!=1)
		adm_table_row_close();

	    if ((!$graphic) || ($ret1===false) || ($ret2===false)) 
		table_row("<small>The RRDTool files for Interface ID ".$graphic["id"]." (from Host ID ".$graphic["host"]."), has not been created by the Poller Process yet.</small>","center",2);
	}

	flush();
    }

    //debug ($aggregation);
        
    foreach ($aggregation as $agg_type=>$agg_data) //for each graph type with aggregation
	if (count($agg_data["ids"]) > 1) { //more than 1 interface of this graph type

	    $image_title = $agg_data["description"]." Aggregation";

	    $filename = "aggr-".uniqid("").".png";

	    $ret3 = performance_graph (&$interfaces,$agg_data["ids"],"$images_real_path/$filename",$agg_type."_aggregation",
		500,175, $image_title,$graph_time_start_unix,$graph_time_stop_unix); //FIXME Fixed Size

	    if ($ret3) 
		switch ($view_type) {
		    case "html":
			table_row(adm_image("$images_rel_path/$filename","","",0,0,$scale_legend),"center",2);
		    break;
		    
		    case "graph":
		    if ($want_graph=="aggr")
			echo join ("",file($images_real_path."/$filename"));
		    break;
		}

	    flush();
	}

    if ($view_type=="html") {
	echo "\n".javascript_refresh("if (self.no_refresh!=1) location.href=\"$REQUEST_URI\";",$refresh_time); 
	adm_footer();
    }
?>
